@@ -9,9 +9,6 @@ use {
         message::MessageHeader,
         pubkey::Pubkey,
         sanitize::{Sanitize, SanitizeError},
-        serialize_utils::{
-            append_slice, append_u16, append_u8, read_pubkey, read_slice, read_u16, read_u8,
-        },
         short_vec, system_instruction, system_program, sysvar, wasm_bindgen,
     },
     lazy_static::lazy_static,
@@ -400,100 +397,13 @@ impl Message {
         (writable_keys, readonly_keys)
     }
 
-    // First encode the number of instructions:
-    // [0..2 - num_instructions
-    //
-    // Then a table of offsets of where to find them in the data
-    //  3..2 * num_instructions table of instruction offsets
-    //
-    // Each instruction is then encoded as:
-    //   0..2 - num_accounts
-    //   2 - meta_byte -> (bit 0 signer, bit 1 is_writable)
-    //   3..35 - pubkey - 32 bytes
-    //   35..67 - program_id
-    //   67..69 - data len - u16
-    //   69..data_len - data
     #[deprecated]
-    pub fn serialize_instructions(&self) -> Vec<u8> {
-        // 64 bytes is a reasonable guess, calculating exactly is slower in benchmarks
-        let mut data = Vec::with_capacity(self.instructions.len() * (32 * 2));
-        append_u16(&mut data, self.instructions.len() as u16);
-        for _ in 0..self.instructions.len() {
-            append_u16(&mut data, 0);
-        }
-        for (i, instruction) in self.instructions.iter().enumerate() {
-            let start_instruction_offset = data.len() as u16;
-            let start = 2 + (2 * i);
-            data[start..start + 2].copy_from_slice(&start_instruction_offset.to_le_bytes());
-            append_u16(&mut data, instruction.accounts.len() as u16);
-            for account_index in &instruction.accounts {
-                let account_index = *account_index as usize;
-                let is_signer = self.is_signer(account_index);
-                let is_writable = self.is_writable(account_index);
-                let mut meta_byte = 0;
-                if is_signer {
-                    meta_byte |= 1 << Self::IS_SIGNER_BIT;
-                }
-                if is_writable {
-                    meta_byte |= 1 << Self::IS_WRITABLE_BIT;
-                }
-                append_u8(&mut data, meta_byte);
-                append_slice(&mut data, self.account_keys[account_index].as_ref());
-            }
-
-            let program_id = &self.account_keys[instruction.program_id_index as usize];
-            append_slice(&mut data, program_id.as_ref());
-            append_u16(&mut data, instruction.data.len() as u16);
-            append_slice(&mut data, &instruction.data);
-        }
-        data
-    }
-
-    const IS_SIGNER_BIT: usize = 0;
-    const IS_WRITABLE_BIT: usize = 1;
-
     pub fn deserialize_instruction(
         index: usize,
         data: &[u8],
     ) -> Result<Instruction, SanitizeError> {
-        let mut current = 0;
-        let num_instructions = read_u16(&mut current, data)?;
-        if index >= num_instructions as usize {
-            return Err(SanitizeError::IndexOutOfBounds);
-        }
-
-        // index into the instruction byte-offset table.
-        current += index * 2;
-        let start = read_u16(&mut current, data)?;
-
-        current = start as usize;
-        let num_accounts = read_u16(&mut current, data)?;
-        let mut accounts = Vec::with_capacity(num_accounts as usize);
-        for _ in 0..num_accounts {
-            let meta_byte = read_u8(&mut current, data)?;
-            let mut is_signer = false;
-            let mut is_writable = false;
-            if meta_byte & (1 << Self::IS_SIGNER_BIT) != 0 {
-                is_signer = true;
-            }
-            if meta_byte & (1 << Self::IS_WRITABLE_BIT) != 0 {
-                is_writable = true;
-            }
-            let pubkey = read_pubkey(&mut current, data)?;
-            accounts.push(AccountMeta {
-                pubkey,
-                is_signer,
-                is_writable,
-            });
-        }
-        let program_id = read_pubkey(&mut current, data)?;
-        let data_len = read_u16(&mut current, data)?;
-        let data = read_slice(&mut current, data, data_len as usize)?;
-        Ok(Instruction {
-            program_id,
-            accounts,
-            data,
-        })
+        #[allow(deprecated)]
+        sysvar::instructions::load_instruction_at(index, data)
     }
 
     pub fn signer_keys(&self) -> Vec<&Pubkey> {
@@ -930,59 +840,6 @@ mod tests {
         );
     }
 
-    #[test]
-    fn test_decompile_instructions() {
-        solana_logger::setup();
-        let program_id0 = Pubkey::new_unique();
-        let program_id1 = Pubkey::new_unique();
-        let id0 = Pubkey::new_unique();
-        let id1 = Pubkey::new_unique();
-        let id2 = Pubkey::new_unique();
-        let id3 = Pubkey::new_unique();
-        let instructions = vec![
-            Instruction::new_with_bincode(program_id0, &0, vec![AccountMeta::new(id0, false)]),
-            Instruction::new_with_bincode(program_id0, &0, vec![AccountMeta::new(id1, true)]),
-            Instruction::new_with_bincode(
-                program_id1,
-                &0,
-                vec![AccountMeta::new_readonly(id2, false)],
-            ),
-            Instruction::new_with_bincode(
-                program_id1,
-                &0,
-                vec![AccountMeta::new_readonly(id3, true)],
-            ),
-        ];
-
-        let message = Message::new(&instructions, Some(&id1));
-        let serialized = message.serialize_instructions();
-        for (i, instruction) in instructions.iter().enumerate() {
-            assert_eq!(
-                Message::deserialize_instruction(i, &serialized).unwrap(),
-                *instruction
-            );
-        }
-    }
-
-    #[test]
-    fn test_decompile_instructions_out_of_bounds() {
-        solana_logger::setup();
-        let program_id0 = Pubkey::new_unique();
-        let id0 = Pubkey::new_unique();
-        let id1 = Pubkey::new_unique();
-        let instructions = vec![
-            Instruction::new_with_bincode(program_id0, &0, vec![AccountMeta::new(id0, false)]),
-            Instruction::new_with_bincode(program_id0, &0, vec![AccountMeta::new(id1, true)]),
-        ];
-
-        let message = Message::new(&instructions, Some(&id1));
-        let serialized = message.serialize_instructions();
-        assert_eq!(
-            Message::deserialize_instruction(instructions.len(), &serialized).unwrap_err(),
-            SanitizeError::IndexOutOfBounds,
-        );
-    }
-
     #[test]
     fn test_program_ids() {
         let key0 = Pubkey::new_unique();
